Module reader

Module reader 

Streaming FASTA/FASTQ reader.

Structs

FastxReader
A streaming reader for FASTA and FASTQ.
ReaderBuilder
Configuration for a FastxReader.
Records
Borrowing iterator returned by FastxReader::records.

Constants

DEFAULT_BUFFER_SIZE
Default read buffer, large enough to hold a full 150 bp read set line and to keep syscall overhead negligible.

Functions

from_stdin
Read records from standard input (gzip is detected from the magic bytes).
open
Open a FASTA/FASTQ file, transparently handling gzip.

Type Aliases

BoxedReader
The boxed reader type produced by open and from_stdin.