pub type BoxedReader = FastxReader<Box<dyn Read + Send>>;Expand description
The boxed reader type produced by open and from_stdin.
Aliased Type
pub struct BoxedReader { /* private fields */ }pub type BoxedReader = FastxReader<Box<dyn Read + Send>>;The boxed reader type produced by open and from_stdin.
pub struct BoxedReader { /* private fields */ }