pub type BoxedWriter = FastxWriter<Box<dyn Write + Send>>;Expand description
The boxed writer type produced by create and WriterBuilder::stdout.
Aliased Type
pub struct BoxedWriter { /* private fields */ }pub type BoxedWriter = FastxWriter<Box<dyn Write + Send>>;The boxed writer type produced by create and WriterBuilder::stdout.
pub struct BoxedWriter { /* private fields */ }