expected_errors

Function expected_errors 

pub fn expected_errors(quality: &[u8], offset: u8) -> f64
Sum of per-base error probabilities — the expected number of wrong bases.

This is the quantity fastp/vsearch filter on, and it is a better read quality summary than the arithmetic mean of Phred scores.