Streaming FASTA/FASTQ reader.
Structs
- Fastx
Reader - A streaming reader for FASTA and FASTQ.
- Reader
Builder - Configuration for a
FastxReader. - Records
- Borrowing iterator returned by
FastxReader::records.
Constants
- DEFAULT_
BUFFER_ SIZE - Default read buffer, large enough to hold a full 150 bp read set line and to keep syscall overhead negligible.
Functions
- from_
stdin - Read records from standard input (gzip is detected from the magic bytes).
- open
- Open a FASTA/FASTQ file, transparently handling gzip.
Type Aliases
- Boxed
Reader - The boxed reader type produced by
openandfrom_stdin.